<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define('THEMEROOT', get_stylesheet_directory_uri());
define('IMAGES', THEMEROOT . '/images');
define('SCRIPTS', THEMEROOT . '/js');
require_once('class-wp-bootstrap-navwalker.php');
require_once('latest_widget.php');


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */

if (!function_exists('alpha_setup')) {
    function alpha_setup()
    {
        /**
         * Make the theme available for translation.
         */
        $lang_dir = THEMEROOT . '/languages';
        load_theme_textdomain('alpha', $lang_dir);


        /**
         * Add support for automatic feed links.
         */
        add_theme_support('automatic-feed-links');
        add_theme_support('widgets');
        add_theme_support('post-thumbnails');


        /**
         * Register nav menus.
         */
        register_nav_menus(
            array(
                'main' => __('القائمة الرئيسية', 'alpha'),
                'footer' => __('قائمة الفوتر', 'alpha'),
				'footer2' => __( 'قائمة الفوتر2 ', 'alpha' )
//				'footer3' => __( 'قائمة الفوتر3 ', 'alpha' ),
//				'footer4' => __( 'قائمة الفوتر4 ', 'alpha' )


            )
        );
    }

    add_action('after_setup_theme', 'alpha_setup');
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if (!function_exists('alpha_scripts')) {
    function alpha_scripts()
    {
        // Adds support for pages with threaded comments
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        // Register scripts
        wp_register_script('popper', 'https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js', array('jquery'), false, true);
        wp_enqueue_script('popper');
        if (is_rtl()) {
            wp_register_script('bootstrap-rtl', SCRIPTS . '/bootstrap-rtl.js', array('jquery'), false, true);
            wp_enqueue_script('bootstrap-rtl');
        } else {
            wp_register_script('bootstrap-js', 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js', array('jquery'), false, true);
            wp_enqueue_script('bootstrap-js');
        }
        wp_register_script('owlcarousel', 'https://cdnjs.cloudflare.com/ajax/libs/OwlCarousel2/2.3.4/owl.carousel.min.js', array('jquery'), false, true);
        wp_enqueue_script('owlcarousel');

        wp_register_script('lazyload',  'https://cdn.jsdelivr.net/npm/vanilla-lazyload@8.17.0/dist/lazyload.min.js', array('jquery'), false, true);
        wp_enqueue_script('lazyload');

        wp_register_script('wow',  'https://cdnjs.cloudflare.com/ajax/libs/wow/1.1.2/wow.min.js', array('jquery'), false, true);
        wp_enqueue_script('wow');

        wp_register_script('custom', SCRIPTS . '/custom.js', array('jquery'), false, true);
        wp_enqueue_script('custom');


        // Load the stylesheets
        wp_enqueue_style('Fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css');
        wp_enqueue_style('animate', 'https://cdnjs.cloudflare.com/ajax/libs/animate.css/3.7.0/animate.min.css');
        wp_enqueue_style('owl.carousel', 'https://cdnjs.cloudflare.com/ajax/libs/OwlCarousel2/2.3.4/assets/owl.carousel.min.css');
//		wp_enqueue_style( 'sinster', THEMEROOT . '/css/sinister.css' );
//		wp_enqueue_style( 'lightslider', THEMEROOT . '/css/lightslider.min.css' );

        if (is_rtl()) {

            wp_enqueue_style('bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.css');
            wp_enqueue_style('rtl', THEMEROOT . '/style.css');

        } else {
            wp_enqueue_style('bootstrap', 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css');
            wp_enqueue_style('en', THEMEROOT . '/en.css');
        }

    }

    add_action('wp_enqueue_scripts', 'alpha_scripts');
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */


register_post_type('slider', array(

    'public' => true,

    'hierarchical' => false,

    'exclude_from_search' => false,

    'has_archive' => true,

    'rewrite' => array('slug' => 'slider'),

    'capability_type' => 'post',

    'menu_icon' => 'dashicons-images-alt2',

    'taxonomies' => array('post_tag'),

    'labels' => array(

        'name' => __('السلايدر','alpha'),

        'singular_name' => __('سلايد','alpha'),

        'menu_name' => __('السلايدر','alpha'),

        'name_admin_bar' => __('سلايد','alpha')
    ),

    'supports' => array('title', 'editor', 'tags', 'thumbnail')

));


/*************************************************/
/* Register Taxonami */
/*************************************************/
//add_action('init', 'create_sections');
//
//function create_sections()
//{
//    register_taxonomy(
//        'sections',
//        'products',
//        array(
//            'label' => __('اقسام المنتجات','alpha'),
//            'hierarchical' => true,
//            'show_ui' => true,
//            'show_admin_column' => true,
//            'show_in_nav_menus' => true,
//            'show_tagcloud' => true,
//            'public' => true
//        )
//
//    );
//
//}




/*************************************************/
/* Page Option */
/*************************************************/
if (function_exists('acf_add_options_page')) {

    acf_add_options_page(array(
        'page_title' => __('اعدادات القالب','alpha'),
        'menu_title' => __('اعدادات القالب','alpha'),
        'menu_slug' => 'theme-general-settings',
        'capability' => 'edit_posts',
        'update_button' => __('حفظ الاعدادات','alpha'),
        'redirect' => false
    ));

}

if (function_exists('acf_add_options_page')) {

    acf_add_options_page(array(
        'page_title' => __('عملائنا','alpha'),
        'menu_title' => __('عملائنا','alpha'),
        'menu_slug' => 'our_clients',
        'capability' => 'edit_posts',
        'update_button' => __('حفظ ونشر','alpha'),
        'redirect' => false
    ));

}

function mytheme_admin_bar_render()
{
    global $wp_admin_bar;
    $wp_admin_bar->add_menu(array(
        'id' => 'themeoptions',
        'title' =>  __('اعدادات القالب', 'alpha'),
        'href' => admin_url('admin.php?page=theme-general-settings')

    ));
}

// and we hook our function via
add_action('wp_before_admin_bar_render', 'mytheme_admin_bar_render');


/*************************************************/
/* Sidebar */
/*************************************************/
if (function_exists('register_sidebar')) {
    register_sidebar(
        array(
            'name' => 'sidebar',
            'id' => 'sidebar',
            'description' => 'Sidebar',
            'before_widget' => '<div class="rest-of-news">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="box-section-title">',
            'after_title' => '</h6>'

        )
    );
}

// remove toolbar items
function shapeSpace_remove_toolbar_node($wp_admin_bar)
{
    $wp_admin_bar->remove_node('ubermenu');
}

add_action('admin_bar_menu', 'shapeSpace_remove_toolbar_node', 999);

